# civic_scraper

## Subpackages

```{toctree}
:maxdepth: 3

civic_scraper.base
civic_scraper.platforms
```

## Submodules

### civic_scraper.runner

```{eval-rst}
.. automodule:: civic_scraper.runner
   :members:
   :undoc-members:
   :show-inheritance:
```

### civic_scraper.utils

```{eval-rst}
.. automodule:: civic_scraper.utils
   :members:
   :undoc-members:
   :show-inheritance:
```
